@@ -14,17 +14,19 @@ impl Opt {
             if let Ok(mut file) = std::fs::File::open(path) {
                 let mut buffer: Vec<u8> = Vec::new();
                 if file.read_to_end(&mut buffer).is_ok() {
-                    toml::from_slice(&buffer).or(Err("Failed to parse config"))
+                    toml::from_slice(&buffer).or(Err("Failed to parse configuration file."))
                 } else {
-                    Err("Failed to read config file")
+                    Err("Failed to read configuration file.")
                 }
             } else {
-                Err("Failed to open file")
+                Err("Failed to open configuration file.")
             }
         } else {
-            Err("File doesn't exist")
+            Err("Failed to locate the file, perhaps it doesn't exist.")
         }
     }
+
+    /// Reads config file specified by MACCHINA_CONF environment variable
     pub fn from_config() -> Result<Opt, &'static str> {
         if let Some(path) = std::env::var_os("MACCHINA_CONF") {
             return Opt::from_config_file(&path);
@@ -46,104 +48,70 @@ impl Opt {
                 }
             }
         }
+
         Ok(Opt::default())
     }
 
+    /// Patches `opt` with the values provided in the command-line
     pub fn patch_args(&mut self, args: Self) {
-        if args.bar {
-            self.bar = true;
-        }
-        if args.box_title.is_some() {
-            self.box_title = args.box_title;
-        }
-        if args.color.is_some() {
-            self.color = args.color;
-        }
-        if args.custom_ascii.is_some() {
-            self.custom_ascii = args.custom_ascii;
-        }
-        if args.custom_ascii_color.is_some() {
-            self.custom_ascii_color = args.custom_ascii_color;
-        }
         if args.version {
             self.version = true;
         }
+
         if args.doctor {
             self.doctor = true;
         }
+
         if args.export_config {
             self.export_config = true;
         }
-        if args.hide.is_some() {
-            self.hide = args.hide;
-        }
-        if args.no_ascii {
-            self.no_ascii = true;
-        }
-        if args.no_bar_delimiter {
-            self.no_bar_delimiter = true;
-        }
-        if args.no_box {
-            self.no_box = true;
-        }
-        if args.no_color {
-            self.no_color = true;
-        }
-        if args.no_separator {
-            self.no_separator = true;
-        }
-        if args.no_title {
-            self.no_title = true;
-        }
-        if args.padding.is_some() {
-            self.padding = args.padding;
-        }
-        if args.palette.is_some() {
-            self.palette = args.palette;
-        }
-        if args.random_color {
-            self.random_color = true;
-        }
-        if args.random_sep_color {
-            self.random_sep_color = true;
-        }
-        if args.separator_color.is_some() {
-            self.separator_color = args.separator_color;
+
+        if args.current_shell {
+            self.current_shell = true;
         }
+
         if args.long_shell {
             self.long_shell = true;
         }
-        if args.long_shell {
-            self.long_kernel = true;
-        }
-        if args.interface.is_some() {
-            self.interface = args.interface;
-        }
-        if args.short_uptime {
-            self.short_uptime = true;
-        }
-        if args.show_only.is_some() {
-            self.show_only = args.show_only;
-        }
-        if args.spacing.is_some() {
-            self.spacing = args.spacing;
-        }
-        if args.theme.is_some() {
-            self.theme = args.theme;
+
+        if args.long_uptime {
+            self.long_uptime = true;
         }
+
         if args.list_themes {
             self.list_themes = true;
         }
-    }
 
-    // Checks for conflicts between the different flags.
-    pub fn check_conflicts(&self) -> Vec<&str> {
-        let mut conflicts = vec![];
-
-        if self.hide.is_some() && self.show_only.is_some() {
-            conflicts.push("hide and show_only");
+        if args.long_kernel {
+            self.long_shell = true;
         }
 
-        conflicts
+        if args.no_ascii {
+            self.no_ascii = true;
+        }
+
+        if args.custom_ascii.is_some() {
+            self.custom_ascii = args.custom_ascii;
+        }
+
+        if args.config.is_some() {
+            self.config = args.config;
+        }
+
+        if args.theme.is_some() {
+            self.theme = args.theme;
+        }
+
+        if args.show.is_some() {
+            self.show = args.show;
+        }
+
+        if args.palette.is_some() {
+            self.palette = args.palette;
+        }
+
+        if args.interface.is_some() {
+            self.interface = args.interface;
+        }
     }
 }
